pub trait AsyncSender<T: Sized + Send + Sync>:
Sized
+ Send
+ Sync {
// Required method
fn send(&self, x: T) -> ControllerResult<()>;
}Expand description
Asynchronous and thread-safe handle to send data over a stream.
See Controller’s documentation for details.
Details about the receiving end are left to the implementor.
Required Methods
Sourcefn send(&self, x: T) -> ControllerResult<()>
fn send(&self, x: T) -> ControllerResult<()>
Enqueue a new value to be sent to all other users without blocking
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".